@@ -22,7 +22,7 @@ from init_helpers.dict_to_dataclass import dict_to_dataclass, T
 
 logger = logging.getLogger(__name__)
 DetectionAnalyzeResult = Type[T]
-AnalyzeResultCallback = Callable[[Type[T]], Awaitable[Any]]
+AnalyzeResultCallback = Callable[[DetectionAnalyzeResult], Awaitable[Any]]
 
 
 class DetectorKafkaConnector(AsyncOnStart):
